# Generated by Django 2.2.5 on 2019-10-18 13:39
from django.db import migrations
from django.utils import timezone


def fill_compliance_saved_at(apps, schema_editor):
    Compliance = apps.get_model("mds", "Compliance")
    # The default value on compliances already computed
    Compliance.objects.update(saved_at=timezone.now())

class Migration(migrations.Migration):

    dependencies = [
        ('mds', '0054_compliance_saved_at_nullable'),
    ]

    operations = [
        migrations.RunPython(fill_compliance_saved_at, migrations.RunPython.noop)
    ]
